@@ -4,7 +4,9 @@ import click
 from click_default_group import DefaultGroup
 
 from . import __version__, console
-from .cli.cfg.commands import cfg
+from .cli.cfg.group import cfg
+from .cli.init.commands import init
+from .cli.new.group import new
 from .cli.plugins.commands import plugins
 from .cli.render.commands import render
 from .constants import EPILOG
@@ -41,6 +43,8 @@ def main(ctx):
 
 main.add_command(cfg)
 main.add_command(plugins)
+main.add_command(init)
+main.add_command(new)
 main.add_command(render)
 
 if __name__ == "__main__":
