@@ -42,7 +42,10 @@ class Homotopy(Animation):
         return lambda p: self.homotopy(*p, t)
 
     def interpolate_submobject(
-        self, submobject: "Mobject", starting_submobject: "Mobject", alpha: float
+        self,
+        submobject: "Mobject",
+        starting_submobject: "Mobject",
+        alpha: float,
     ) -> None:
         submobject.points = starting_submobject.points
         submobject.apply_function(
@@ -52,9 +55,12 @@ class Homotopy(Animation):
 
 class SmoothedVectorizedHomotopy(Homotopy):
     def interpolate_submobject(
-        self, submobject: "Mobject", starting_submobject: "Mobject", alpha: float
+        self,
+        submobject: "Mobject",
+        starting_submobject: "Mobject",
+        alpha: float,
     ) -> None:
-        Homotopy.interpolate_submobject(self, submobject, starting_submobject, alpha)
+        super().interpolate_submobject(submobject, starting_submobject, alpha)
         submobject.make_smooth()
 
 
@@ -67,12 +73,15 @@ class ComplexHomotopy(Homotopy):
         """
 
         def homotopy(
-            x: float, y: float, z: float, t: float
+            x: float,
+            y: float,
+            z: float,
+            t: float,
         ) -> Tuple[float, float, float]:
             c = complex_homotopy(complex(x, y), t)
             return (c.real, c.imag, z)
 
-        Homotopy.__init__(self, homotopy, mobject, **kwargs)
+        super().__init__(homotopy, mobject, **kwargs)
 
 
 class PhaseFlow(Animation):
