@@ -9,7 +9,7 @@ import operator as op
 import pathlib
 import time
 from functools import reduce
-from typing import Union
+from typing import Any, Union
 
 import cairo
 import numpy as np
@@ -454,16 +454,27 @@ class Camera:
         return not reduce(
             op.or_,
             [
-                mobject.get_right()[0] < fc[0] - fw,
-                mobject.get_bottom()[1] > fc[1] + fh,
-                mobject.get_left()[0] > fc[0] + fw,
-                mobject.get_top()[1] < fc[1] - fh,
+                mobject.get_right()[0] < fc[0] - fw / 2,
+                mobject.get_bottom()[1] > fc[1] + fh / 2,
+                mobject.get_left()[0] > fc[0] + fw / 2,
+                mobject.get_top()[1] < fc[1] - fh / 2,
             ],
         )
 
-    def capture_mobject(
-        self, mobject, **kwargs
-    ):  # TODO Write better docstrings for this method.
+    def capture_mobject(self, mobject: Mobject, **kwargs: Any):
+        """Capture mobjects by storing it in :attr:`pixel_array`.
+
+        This is a single-mobject version of :meth:`capture_mobjects`.
+
+        Parameters
+        ----------
+        mobject
+            Mobject to capture.
+
+        kwargs
+            Keyword arguments to be passed to :meth:`get_mobjects_to_display`.
+
+        """
         return self.capture_mobjects([mobject], **kwargs)
 
     def capture_mobjects(self, mobjects, **kwargs):
@@ -1095,7 +1106,7 @@ class Camera:
         big_sum = op.add(config["pixel_height"], config["pixel_width"])
         this_sum = op.add(self.pixel_height, self.pixel_width)
         factor = fdiv(big_sum, this_sum)
-        return 1 + (thickness - 1) / factor
+        return 1 + (thickness - 1) * factor
 
     def get_thickening_nudges(self, thickness):
         """
