@@ -9,7 +9,7 @@ from ... import logger
 def validate_gui_location(ctx, param, value):
     if value:
         try:
-            x_offset, y_offset = map(int, re.split(";|,|-", value))
+            x_offset, y_offset = map(int, re.split(r"[;,\-]", value))
             return (x_offset, y_offset)
         except Exception:
             logger.error("GUI location option is invalid.")
@@ -90,4 +90,10 @@ global_options = option_group(
         help="Force window to open when using the opengl renderer, intended for debugging as it may impact performance",
         default=False,
     ),
+    option(
+        "--dry_run",
+        is_flag=True,
+        help="Renders animations without outputting image or video files and disables the window",
+        default=False,
+    ),
 )
