@@ -3,6 +3,8 @@ import re
 import click
 from cloup import option, option_group
 
+from manim.constants import QUALITIES
+
 from ... import logger
 
 
@@ -15,7 +17,7 @@ def validate_scene_range(ctx, param, value):
 
     if value:
         try:
-            start, end = map(int, re.split(";|,|-", value))
+            start, end = map(int, re.split(r"[;,\-]", value))
             return start, end
         except Exception:
             logger.error("Couldn't determine a range for -n option.")
@@ -25,7 +27,7 @@ def validate_scene_range(ctx, param, value):
 def validate_resolution(ctx, param, value):
     if value:
         try:
-            start, end = map(int, re.split(";|,|-", value))
+            start, end = map(int, re.split(r"[;,\-]", value))
             return (start, end)
         except Exception:
             logger.error("Resolution option is invalid.")
@@ -59,15 +61,20 @@ render_options = option_group(
         "-q",
         "--quality",
         default=None,
-        type=click.Choice(["l", "m", "h", "p", "k"], case_sensitive=False),
-        help="""
-            Render quality at the follow resolution framerates, respectively:
-            854x480 30FPS,
-            1280x720 30FPS,
-            1920x1080 60FPS,
-            2560x1440 60FPS,
-            3840x2160 60FPS
-            """,
+        type=click.Choice(
+            list(reversed([q["flag"] for q in QUALITIES.values() if q["flag"]])),
+            case_sensitive=False,
+        ),
+        help="Render quality at the follow resolution framerates, respectively: "
+        + ", ".join(
+            reversed(
+                [
+                    f'{q["pixel_width"]}x{q["pixel_height"]} {q["frame_rate"]}FPS'
+                    for q in QUALITIES.values()
+                    if q["flag"]
+                ]
+            )
+        ),
     ),
     option(
         "-r",
@@ -122,6 +129,12 @@ render_options = option_group(
         is_flag=True,
         help="Save as a gif (Deprecated).",
     ),
+    option(
+        "--save_sections",
+        default=None,
+        is_flag=True,
+        help="Save section videos in addition to movie file.",
+    ),
     option(
         "-s",
         "--save_last_frame",
