@@ -59,6 +59,7 @@ __all__ = [
     "DEFAULT_POINT_DENSITY_2D",
     "DEFAULT_POINT_DENSITY_1D",
     "DEFAULT_STROKE_WIDTH",
+    "DEFAULT_FONT_SIZE",
     "PI",
     "TAU",
     "DEGREES",
@@ -189,6 +190,7 @@ DEFAULT_WAIT_TIME: float = 1.0
 DEFAULT_POINT_DENSITY_2D: int = 25
 DEFAULT_POINT_DENSITY_1D: int = 10
 DEFAULT_STROKE_WIDTH: int = 4
+DEFAULT_FONT_SIZE: float = 48
 
 # Mathematical constants
 PI: float = np.pi
