@@ -98,65 +98,94 @@ def _determine_graph_layout(
 
 
 def _tree_layout(
-    G: nx.classes.graph.Graph,
+    T: nx.classes.graph.Graph,
     root_vertex: Union[Hashable, None],
-    scale: float,
-) -> dict:
-    result = {root_vertex: np.array([0, 0, 0])}
+    scale: Union[float, tuple] = 2,
+    orientation: str = "down",
+):
+    children = {root_vertex: list(T.neighbors(root_vertex))}
 
-    if not nx.is_tree(G):
+    if not nx.is_tree(T):
         raise ValueError("The tree layout must be used with trees")
     if root_vertex is None:
         raise ValueError("The tree layout requires the root_vertex parameter")
 
-    def _recursive_position_for_row(
-        G: nx.classes.graph.Graph,
-        result: dict,
-        two_rows_before: List[Hashable],
-        last_row: List[Hashable],
-        current_height: float,
-    ):
-        new_row = []
-        for v in last_row:
-            for x in G.neighbors(v):
-                if x not in two_rows_before:
-                    new_row.append(x)
+    # The following code is SageMath's tree layout implementation, taken from
+    # https://github.com/sagemath/sage/blob/cc60cfebc4576fed8b01f0fc487271bdee3cefed/src/sage/graphs/graph_plot.py#L1447
 
-        new_row_length = len(new_row)
+    # Always make a copy of the children because they get eaten
+    stack = [[u for u in children[root_vertex]]]
+    stick = [root_vertex]
+    parent = {u: root_vertex for u in children[root_vertex]}
+    pos = {}
+    obstruction = [0.0] * len(T)
+    if orientation == "down":
+        o = -1
+    else:
+        o = 1
 
-        if new_row_length == 0:
-            return
+    def slide(v, dx):
+        """
+        Shift the vertex v and its descendants to the right by dx.
+        Precondition: v and its descendents have already had their
+        positions computed.
+        """
+        level = [v]
+        while level:
+            nextlevel = []
+            for u in level:
+                x, y = pos[u]
+                x += dx
+                obstruction[y] = max(x + 1, obstruction[y])
+                pos[u] = x, y
+                nextlevel += children[u]
+            level = nextlevel
 
-        if new_row_length == 1:
-            result[new_row[0]] = np.array([0, current_height, 0])
-        else:
-            for i in range(new_row_length):
-                result[new_row[i]] = np.array(
-                    [-1 + 2 * i / (new_row_length - 1), current_height, 0],
-                )
+    while stack:
+        C = stack[-1]
+        if not C:
+            p = stick.pop()
+            stack.pop()
+            cp = children[p]
+            y = o * len(stack)
+            if not cp:
+                x = obstruction[y]
+                pos[p] = x, y
+            else:
+                x = sum(pos[c][0] for c in cp) / float(len(cp))
+                pos[p] = x, y
+                ox = obstruction[y]
+                if x < ox:
+                    slide(p, ox - x)
+                    x = ox
+            obstruction[y] = x + 1
+            continue
 
-        _recursive_position_for_row(
-            G,
-            result,
-            two_rows_before=last_row,
-            last_row=new_row,
-            current_height=current_height + 1,
-        )
+        t = C.pop()
+        pt = parent[t]
 
-    _recursive_position_for_row(
-        G,
-        result,
-        two_rows_before=[],
-        last_row=[root_vertex],
-        current_height=1,
-    )
+        ct = [u for u in list(T.neighbors(t)) if u != pt]
+        for c in ct:
+            parent[c] = t
+        children[t] = copy(ct)
 
-    height = max(map(lambda v: result[v][1], result))
+        stack.append(ct)
+        stick.append(t)
 
-    return {
-        v: np.array([pos[0], 1 - 2 * pos[1] / height, pos[2]]) * scale / 2
-        for v, pos in result.items()
-    }
+    # the resulting layout is then rescaled again to fit on Manim's canvas
+
+    x_min = min(pos.values(), key=lambda t: t[0])[0]
+    x_max = max(pos.values(), key=lambda t: t[0])[0]
+    y_min = min(pos.values(), key=lambda t: t[1])[1]
+    y_max = max(pos.values(), key=lambda t: t[1])[1]
+    center = np.array([x_min + x_max, y_min + y_max, 0]) / 2
+    height = y_max - y_min
+    width = x_max - x_min
+    if isinstance(scale, (float, int)):
+        sf = 2 * scale / max(width, height)
+    else:
+        sf = np.array([2 * scale[0] / width, 2 * scale[1] / height, 0])
+    return {v: (np.array([x, y, 0]) - center) * sf for v, (x, y) in pos.items()}
 
 
 class Graph(VMobject, metaclass=ConvertToOpenGL):
@@ -199,7 +228,9 @@ class Graph(VMobject, metaclass=ConvertToOpenGL):
     layout_scale
         The scale of automatically generated layouts: the vertices will
         be arranged such that the coordinates are located within the
-        interval ``[-scale, scale]``. Default: 2.
+        interval ``[-scale, scale]``. Some layouts accept a tuple ``(scale_x, scale_y)``
+        causing the first coordinate to be in the interval ``[-scale_x, scale_x]``,
+        and the second in ``[-scale_y, scale_y]``. Default: 2.
     layout_config
         Only for automatically generated layouts. A dictionary whose entries
         are passed as keyword arguments to the automatic layout algorithm
@@ -356,10 +387,10 @@ class Graph(VMobject, metaclass=ConvertToOpenGL):
         self,
         vertices: List[Hashable],
         edges: List[Tuple[Hashable, Hashable]],
-        labels: bool = False,
+        labels: Union[bool, dict] = False,
         label_fill_color: str = BLACK,
         layout: Union[str, dict] = "spring",
-        layout_scale: float = 2,
+        layout_scale: Union[float, tuple] = 2,
         layout_config: Union[dict, None] = None,
         vertex_type: Type["Mobject"] = Dot,
         vertex_config: Union[dict, None] = None,
@@ -633,7 +664,9 @@ class Graph(VMobject, metaclass=ConvertToOpenGL):
         animation = anim_args.pop("animation", Create)
 
         vertex_mobjects = self.add_vertices(*args, **kwargs)
-        return AnimationGroup(*(animation(v, **anim_args) for v in vertex_mobjects))
+        return AnimationGroup(
+            *(animation(v, **anim_args) for v in vertex_mobjects), group=self
+        )
 
     def _remove_vertex(self, vertex):
         """Remove a vertex (as well as all incident edges) from the graph.
@@ -704,7 +737,9 @@ class Graph(VMobject, metaclass=ConvertToOpenGL):
         animation = anim_args.pop("animation", Uncreate)
 
         mobjects = self.remove_vertices(*vertices)
-        return AnimationGroup(*(animation(mobj, **anim_args) for mobj in mobjects))
+        return AnimationGroup(
+            *(animation(mobj, **anim_args) for mobj in mobjects), group=self
+        )
 
     def _add_edge(
         self,
@@ -817,7 +852,9 @@ class Graph(VMobject, metaclass=ConvertToOpenGL):
         animation = anim_args.pop("animation", Create)
 
         mobjects = self.add_edges(*args, **kwargs)
-        return AnimationGroup(*(animation(mobj, **anim_args) for mobj in mobjects))
+        return AnimationGroup(
+            *(animation(mobj, **anim_args) for mobj in mobjects), group=self
+        )
 
     def _remove_edge(self, edge: Tuple[Hashable]):
         """Remove an edge from the graph.
@@ -873,7 +910,9 @@ class Graph(VMobject, metaclass=ConvertToOpenGL):
         animation = anim_args.pop("animation", Uncreate)
 
         mobjects = self.remove_edges(*edges)
-        return AnimationGroup(*(animation(mobj, **anim_args) for mobj in mobjects))
+        return AnimationGroup(
+            *(animation(mobj, **anim_args) for mobj in mobjects), group=self
+        )
 
     @staticmethod
     def from_networkx(nxgraph: nx.classes.graph.Graph, **kwargs) -> "Graph":
