@@ -149,12 +149,6 @@ class Brace(SVGPathMobject):
 
 
 class BraceLabel(VMobject, metaclass=ConvertToOpenGL):
-    @deprecated_params(
-        params="label_scale",
-        since="v0.10.0",
-        until="v0.11.0",
-        message="Use font_size instead. To convert old scale factors to font size, multiply by 48.",
-    )
     def __init__(
         self,
         obj,
@@ -165,12 +159,6 @@ class BraceLabel(VMobject, metaclass=ConvertToOpenGL):
         buff=0.2,
         **kwargs
     ):
-        label_scale = kwargs.pop("label_scale", None)
-        if label_scale:
-            self.font_size = label_scale * DEFAULT_FONT_SIZE
-        else:
-            self.font_size = font_size
-
         self.label_constructor = label_constructor
         super().__init__(**kwargs)
 
