@@ -20,7 +20,7 @@ Examples
     class TextAlignment(Scene):
         def construct(self):
             title = Text("K-means clustering and Logistic Regression", color=WHITE)
-            title.scale_in_place(0.75)
+            title.scale(0.75)
             self.add(title.to_edge(UP))
 
             t1 = Text("1. Measuring").set_color(WHITE)
@@ -35,7 +35,7 @@ Examples
             t4 = Text("4. Prediction").set_color(WHITE)
             t4.next_to(t3, direction=DOWN, aligned_edge=LEFT)
 
-            x = VGroup(t1, t2, t3, t4).scale_in_place(0.7)
+            x = VGroup(t1, t2, t3, t4).scale(0.7)
             x.set_opacity(0.5)
             x.submobjects[1].set_opacity(1)
             self.add(x)
@@ -148,7 +148,7 @@ class OpenGLParagraph(OpenGLVGroup):
                     char_index_counter : char_index_counter
                     + lines_str_list[line_index].__len__()
                     + 1
-                ]
+                ],
             )
             char_index_counter += lines_str_list[line_index].__len__() + 1
         self.lines = []
@@ -160,10 +160,10 @@ class OpenGLParagraph(OpenGLVGroup):
             self.lines_initial_positions.append(self.lines[0][line_no].get_center())
         self.lines.append([])
         self.lines[1].extend(
-            [self.alignment for _ in range(chars_lines_text_list.__len__())]
+            [self.alignment for _ in range(chars_lines_text_list.__len__())],
         )
-        OpenGLVGroup.__init__(
-            self, *(self.lines[0][i] for i in range(self.lines[0].__len__())), **config
+        super().__init__(
+            *(self.lines[0][i] for i in range(self.lines[0].__len__())), **config
         )
         self.move_to(np.array([0, 0, 0]))
         if self.alignment:
@@ -226,7 +226,7 @@ class OpenGLParagraph(OpenGLVGroup):
         self.lines[1] = [None for _ in range(self.lines[0].__len__())]
         for line_no in range(0, self.lines[0].__len__()):
             self[line_no].move_to(
-                self.get_center() + self.lines_initial_positions[line_no]
+                self.get_center() + self.lines_initial_positions[line_no],
             )
         return self
 
@@ -255,7 +255,7 @@ class OpenGLParagraph(OpenGLVGroup):
         self.lines[1][line_no] = alignment
         if self.lines[1][line_no] == "center":
             self[line_no].move_to(
-                np.array([self.get_center()[0], self[line_no].get_center()[1], 0])
+                np.array([self.get_center()[0], self[line_no].get_center()[1], 0]),
             )
         elif self.lines[1][line_no] == "right":
             self[line_no].move_to(
@@ -264,8 +264,8 @@ class OpenGLParagraph(OpenGLVGroup):
                         self.get_right()[0] - self[line_no].width / 2,
                         self[line_no].get_center()[1],
                         0,
-                    ]
-                )
+                    ],
+                ),
             )
         elif self.lines[1][line_no] == "left":
             self[line_no].move_to(
@@ -274,8 +274,8 @@ class OpenGLParagraph(OpenGLVGroup):
                         self.get_left()[0] + self[line_no].width / 2,
                         self[line_no].get_center()[1],
                         0,
-                    ]
-                )
+                    ],
+                ),
             )
 
 
@@ -451,8 +451,7 @@ class OpenGLText(OpenGLSVGMobject):
             self.line_spacing = self.size + self.size * self.line_spacing
         file_name = self.text2svg()
         PangoUtils.remove_last_M(file_name)
-        OpenGLSVGMobject.__init__(
-            self,
+        super().__init__(
             file_name,
             color=color,
             fill_opacity=fill_opacity,
@@ -514,7 +513,7 @@ class OpenGLText(OpenGLSVGMobject):
                     space.move_to(self.submobjects[submobjects_char_index].get_center())
                 else:
                     space.move_to(
-                        self.submobjects[submobjects_char_index - 1].get_center()
+                        self.submobjects[submobjects_char_index - 1].get_center(),
                     )
                 chars.add(space)
             else:
@@ -931,7 +930,7 @@ class OpenGLMarkupText(OpenGLSVGMobject):
         colormap = self.extract_color_tags()
         if len(colormap) > 0:
             logger.warning(
-                'Using <color> tags in MarkupText is deprecated. Please use <span foreground="..."> instead.'
+                'Using <color> tags in MarkupText is deprecated. Please use <span foreground="..."> instead.',
             )
         gradientmap = self.extract_gradient_tags()
 
@@ -939,7 +938,7 @@ class OpenGLMarkupText(OpenGLSVGMobject):
             raise ValueError(
                 f"Pango cannot parse your markup in {self.text}. "
                 "Please check for typos, unmatched tags or unescaped "
-                "special chars like < and &."
+                "special chars like < and &.",
             )
 
         if self.line_spacing == -1:
@@ -949,8 +948,7 @@ class OpenGLMarkupText(OpenGLSVGMobject):
 
         file_name = self.text2svg()
         PangoUtils.remove_last_M(file_name)
-        OpenGLSVGMobject.__init__(
-            self,
+        super().__init__(
             file_name,
             fill_opacity=fill_opacity,
             stroke_width=stroke_width,
@@ -1095,7 +1093,7 @@ class OpenGLMarkupText(OpenGLSVGMobject):
                     "to": tag.group(2),
                     "start_offset": start_offset,
                     "end_offset": end_offset,
-                }
+                },
             )
         self.text = re.sub("<gradient[^>]+>(.+?)</gradient>", r"\1", self.text, 0, re.S)
         return gradientmap
@@ -1137,7 +1135,7 @@ class OpenGLMarkupText(OpenGLSVGMobject):
                     "color": tag.group(1),
                     "start_offset": start_offset,
                     "end_offset": end_offset,
-                }
+                },
             )
         self.text = re.sub("<color[^>]+>(.+?)</color>", r"\1", self.text, 0, re.S)
         return colormap
