@@ -358,14 +358,14 @@ class MathTex(SingleStringMathTex):
                 # For cases like empty tex_strings, we want the corresponding
                 # part of the whole MathTex to be a VectorizedPoint
                 # positioned in the right part of the MathTex
-                sub_tex_mob.set_submobjects([VectorizedPoint()])
+                sub_tex_mob.submobjects = [VectorizedPoint()]
                 last_submob_index = min(curr_index, len(self.submobjects) - 1)
                 sub_tex_mob.move_to(self.submobjects[last_submob_index], RIGHT)
             else:
-                sub_tex_mob.set_submobjects(self.submobjects[curr_index:new_index])
+                sub_tex_mob.submobjects = self.submobjects[curr_index:new_index]
             new_submobjects.append(sub_tex_mob)
             curr_index = new_index
-        self.set_submobjects(new_submobjects)
+        self.submobjects = new_submobjects
         return self
 
     def get_parts_by_tex(self, tex, substring=True, case_sensitive=True):
@@ -510,12 +510,6 @@ class Title(Tex):
 
     """
 
-    @deprecated_params(
-        params="scale_factor",
-        since="v0.10.0",
-        until="v0.11.0",
-        message="Use font_size instead. To convert old scale factors to font size, multiply by 48.",
-    )
     def __init__(
         self,
         *text_parts,
@@ -524,9 +518,6 @@ class Title(Tex):
         underline_buff=MED_SMALL_BUFF,
         **kwargs,
     ):
-        scale_factor = kwargs.pop("scale_factor", None)
-        if scale_factor:
-            kwargs["font_size"] = DEFAULT_FONT_SIZE * scale_factor
 
         self.include_underline = include_underline
         self.match_underline_width_to_text = match_underline_width_to_text
