@@ -34,7 +34,7 @@ from ...utils.bezier import (
     proportions_along_bezier_curve_for_point,
 )
 from ...utils.color import BLACK, WHITE, color_to_rgba
-from ...utils.deprecation import deprecated, deprecated_params
+from ...utils.deprecation import deprecated
 from ...utils.iterables import make_even, stretch_array_to_length, tuplify
 from ...utils.simple_functions import clip_in_place
 from ...utils.space_ops import rotate_vector, shoelace_direction
@@ -51,7 +51,25 @@ from .opengl_vectorized_mobject import OpenGLVMobject
 
 
 class VMobject(Mobject):
-    """A vectorized mobject."""
+    """A vectorized mobject.
+
+    Parameters
+    ----------
+    background_stroke_color
+        The purpose of background stroke is to have something
+        that won't overlap fill, e.g.  For text against some
+        textured background.
+    sheen_factor
+        When a color c is set, there will be a second color
+        computed based on interpolating c to WHITE by with
+        sheen_factor, and the display will gradient to this
+        secondary color in the direction of sheen_direction.
+    close_new_points
+        Indicates that it will not be displayed, but
+        that it should count in parent mobject's path
+    tolerance_point_for_equality
+        This is within a pixel
+    """
 
     def __init__(
         self,
@@ -60,28 +78,17 @@ class VMobject(Mobject):
         stroke_color=None,
         stroke_opacity=1.0,
         stroke_width=DEFAULT_STROKE_WIDTH,
-        # The purpose of background stroke is to have
-        # something that won't overlap the fill, e.g.
-        # For text against some textured background
         background_stroke_color=BLACK,
         background_stroke_opacity=1.0,
         background_stroke_width=0,
-        # When a color c is set, there will be a second color
-        # computed based on interpolating c to WHITE by with
-        # sheen_factor, and the display will gradient to this
-        # secondary color in the direction of sheen_direction.
         sheen_factor=0.0,
         sheen_direction=UL,
-        # Indicates that it will not be displayed, but
-        # that it should count in parent mobject's path
         close_new_points=False,
         pre_function_handle_to_anchor_scale_factor=0.01,
         make_smooth_after_applying_functions=False,
         background_image=None,
         shade_in_3d=False,
-        # This is within a pixel
-        # TODO, do we care about accounting for
-        # varying zoom levels?
+        # TODO, do we care about accounting for varying zoom levels?
         tolerance_for_point_equality=1e-6,
         n_points_per_cubic_curve=4,
         **kwargs,
@@ -2221,17 +2228,11 @@ class DashedVMobject(VMobject, metaclass=ConvertToOpenGL):
 
     """
 
-    @deprecated_params(
-        params="positive_space_ratio dash_spacing",
-        since="v0.9.0",
-        message="Use dashed_ratio instead of positive_space_ratio.",
-    )
     def __init__(
         self, vmobject, num_dashes=15, dashed_ratio=0.5, color=WHITE, **kwargs
     ):
-        # Simplify with removal of deprecation warning
-        self.dash_spacing = kwargs.pop("dash_spacing", None)  # Unused param
-        self.dashed_ratio = kwargs.pop("positive_space_ratio", None) or dashed_ratio
+
+        self.dashed_ratio = dashed_ratio
         self.num_dashes = num_dashes
         super().__init__(color=color, **kwargs)
         r = self.dashed_ratio
