@@ -1,5 +1,6 @@
 import time
 import typing
+from typing import Any
 
 import numpy as np
 
@@ -13,43 +14,6 @@ from ..utils.exceptions import EndSceneEarlyException
 from ..utils.iterables import list_update
 
 
-def handle_play_like_call(func):
-    """
-    This method is used internally to wrap the
-    passed function, into a function that
-    actually writes to the video stream.
-    Simultaneously, it also adds to the number
-    of animations played.
-
-    Parameters
-    ----------
-    func : function
-        The play() like function that has to be
-        written to the video file stream.
-
-    Returns
-    -------
-    function
-        The play() like function that can now write
-        to the video file stream.
-    """
-
-    # NOTE : This is only kept for OpenGL renderer.
-    # The play logic of the cairo renderer as been refactored and does not need this function anymore.
-    # When OpenGL renderer will have a proper testing system,
-    # the play logic of the latter has to be refactored in the same way the cairo renderer has been, and thus this
-    # method has to be deleted.
-
-    def wrapper(self, scene, *args, **kwargs):
-        self.animation_start_time = time.time()
-        self.file_writer.begin_animation(not self.skip_animations)
-        func(self, scene, *args, **kwargs)
-        self.file_writer.end_animation(not self.skip_animations)
-        self.num_plays += 1
-
-    return wrapper
-
-
 class CairoRenderer:
     """A renderer using Cairo.
 
@@ -67,7 +31,6 @@ class CairoRenderer:
         # All of the following are set to EITHER the value passed via kwargs,
         # OR the value stored in the global config dict at the time of
         # _instance construction_.
-        self.file_writer = None
         self._file_writer_class = file_writer_class
         camera_cls = camera_class if camera_class is not None else Camera
         self.camera = camera_cls()
@@ -79,7 +42,7 @@ class CairoRenderer:
         self.static_image = None
 
     def init_scene(self, scene):
-        self.file_writer = self._file_writer_class(
+        self.file_writer: Any = self._file_writer_class(
             self,
             scene.__class__.__name__,
         )
@@ -95,6 +58,7 @@ class CairoRenderer:
         if self.skip_animations:
             logger.debug(f"Skipping animation {self.num_plays}")
             hash_current_animation = None
+            self.time += scene.duration
         else:
             if config["disable_caching"]:
                 logger.info("Caching disabled.")
@@ -112,6 +76,7 @@ class CairoRenderer:
                         {"hash_current_animation": hash_current_animation},
                     )
                     self.skip_animations = True
+                    self.time += scene.duration
         # adding None as a partial movie file will make file_writer ignore the latter.
         self.file_writer.add_partial_movie_file(hash_current_animation)
         self.animations_hashes.append(hash_current_animation)
@@ -204,9 +169,9 @@ class CairoRenderer:
             The number of times to add frame.
         """
         dt = 1 / self.camera.frame_rate
-        self.time += num_frames * dt
         if self.skip_animations:
             return
+        self.time += num_frames * dt
         for _ in range(num_frames):
             self.file_writer.write_frame(frame)
 
@@ -267,6 +232,9 @@ class CairoRenderer:
         the number of animations that need to be played, and
         raises an EndSceneEarlyException if they don't correspond.
         """
+        # there is always at least one section -> no out of bounds here
+        if self.file_writer.sections[-1].skip_animations:
+            self.skip_animations = True
         if config["save_last_frame"]:
             self.skip_animations = True
         if (
